[PATCH] VPM-B Tests: Adjust known Subsurface runtimes

Rick Walsh rickmwalsh at gmail.com
Sat Aug 29 07:19:35 PDT 2015


The last couple of changes means some calculated runtimes have changed by a
minute or two, but still within the benchmark range.

Signed-off-by: Rick Walsh <rickmwalsh at gmail.com>
---
 tests/testplan.cpp | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/tests/testplan.cpp b/tests/testplan.cpp
index c334265..3535f9d 100644
--- a/tests/testplan.cpp
+++ b/tests/testplan.cpp
@@ -385,8 +385,8 @@ void TestPlan::testVpmbMetric60m30minTx()
 	QCOMPARE(ev->gas.index, 1);
 	QCOMPARE(ev->value, 50);
 	QCOMPARE(get_depth_at_time(&displayed_dive.dc, ev->time.seconds), 21000);
-	// check benchmark run time of 89 minutes, and known Subsurface runtime of 89 minutes
-	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 89u * 60u + 20u, 89u * 60u + 20u));
+	// check benchmark run time of 89 minutes, and known Subsurface runtime of 88 minutes
+	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 89u * 60u + 20u, 88u * 60u + 20u));
 }
 
 void TestPlan::testVpmbMetric100m60min()
@@ -423,8 +423,8 @@ void TestPlan::testVpmbMetric100m60min()
 	QCOMPARE(ev->gas.index, 2);
 	QCOMPARE(ev->value, 100);
 	QCOMPARE(get_depth_at_time(&displayed_dive.dc, ev->time.seconds), 6000);
-	// check benchmark run time of 311 minutes, and known Subsurface runtime of 309 minutes
-	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 311u * 60u + 20u, 309u * 60u + 20u));
+	// check benchmark run time of 311 minutes, and known Subsurface runtime of 312 minutes
+	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 311u * 60u + 20u, 312u * 60u + 20u));
 }
 
 void TestPlan::testVpmbMetricMultiLevelAir()
@@ -449,8 +449,8 @@ void TestPlan::testVpmbMetricMultiLevelAir()
 
 	// print first ceiling
 	printf("First ceiling %.1f m\n", (mbar_to_depth(first_ceiling_pressure.mbar, &displayed_dive) * 0.001));
-	// check benchmark run time of 167 minutes, and known Subsurface runtime of 169 minutes
-	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 167u * 60u + 20u, 169u * 60u + 20u));
+	// check benchmark run time of 167 minutes, and known Subsurface runtime of 168 minutes
+	QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 167u * 60u + 20u, 168u * 60u + 20u));
 }
 
 void TestPlan::testVpmbMetric100m10min()
-- 
2.4.3



More information about the subsurface mailing list